# Data and code associated with McIntosh, A.L.S., Langley, L.P., Hilton, G.M., Shaw, J.M., and Bearhop, S. 2024 "Flying without fear: Shooting disturbance has little effect on site preferences in a conflict goose species" Journal of Applied Ecology

## Contact information:

Please contact Aimée McIntosh ([a.l.s.mcintosh@exeter.ac.uk](mailto:a.l.s.mcintosh@exeter.ac.uk)) for additional information about the analysis and data.

## Project Summary:

This data was collected as part of a PhD funded by the Natural Environment Research Council (NERC) in collaboration with the Wildfowl and Wetlands Trust (WWT) and NatureScot (formally Scottish Natural Heritage)

## Description of data and file structure:

R code for each habitat selection model is found in "McIntosh2024_RSF_Model_Code.R"

### 1. Overall habitat selection:

Data file: "Overall_Hab_Model_Data.csv"

Columns in the file include:
i) Winter <- Winter year
ii) Shooting <-  Field-scale classification of shooting management designation 
iii) TOD <- Time of day (Day/Night)
iv) ceh_simp_hab <- Habitat classification
v) Case <- Binomial numeric designation of real GPS fixes (1) and pseudoabsences (0)
vi) weight <- Initial weight of 1 assigned to all GPS fixes (real and pseudoabsences)
vii) Used <- Two-level factor classification of real GPS fixes (Used) and pseudoabsences (Avail)
viii) Dist_roost <- Distance to nearest roost (m)
ix) Shoot_Tot <- Field-specific total number of shooting events in a single winter

### 2. Improved grasssland field selection - Management designation:

Data file: "Imp_Grass_Management_Model_Data.csv"
This file includes only real GPS fixes and pseudoabsences that were previously classified as "Improved grassland"

Columns in the file include:
i) Shooting <-  Field-scale classification of shooting management designation (Yes/No)
ii) tod\_ <- Time of day (Day/Night)
iii) weight <- Initial weight of 1 assigned to all GPS fixes (real and pseudoabsences)
iii) weight2 <- Weighted data point of 5 assigned to all real GPS fixes and 1 for pseudoabsences
iv) Used <- Two-level factor classification of real GPS fixes (Used) and pseudoabsences (Avail)
v) Case <- Binomial numeric designation of real GPS fixes (1) and pseudoabsences (0)
vi) Winter <- Winter year

### 3. Improved grassland field selection - Shooting disturbance designation:

Data file: "Shoot_Field_Disturbance_Model_Data.csv"
This file includes only real GPS fixes and pseudoabsences of improved grassland fields that were classified as "NatureScot Shooting"

Columns in the file include:
i) Winter <- Winter year
ii) tod\_ <- Time of day (Day/Night)
iii) case\_ <- Classification of real GPS fixes (TRUE) and pseudoabsences (FALSE)
iv) Roost_Dist <- Distance to nearest roost (m)
v) Shot_2019 <- Field-specific shooting disturbance classification in 2019 (Zero/No/Yes)
vi) Shot_2020 <- Field-specific shooting disturbance classification in 2020 (Zero/No/Yes)
vii) Case <- Binomial numeric designation of real GPS fixes (1) and pseudoabsences (0)
viii) weight <- Initial weight of 1 assigned to all GPS fixes (real and pseudoabsences)
ix) weight2 <- Weighted data point of 5 assigned to all real GPS fixes and 1 for pseudoabsences

### 4. Improved grassland field selection - Shooting intensity designation:

Data file: "Shoot_Intensity_Model_Data.csv"

Columns in the file include:
i) Winter <- Winter year
ii) tod\_ <- Time of day (Day/Night)
iii) case\_ <- Classification of real GPS fixes (TRUE) and pseudoabsences (FALSE)
iv) Dist_Roost <- Distance to nearest roost (m)
v) Shooting <- Field-scale classification of shooting management designation (Zero/Low/High)
vi) Case <- Binomial numeric designation of real GPS fixes (1) and pseudoabsences (0)
vii) weight <- Initial weight of 1 assigned to all GPS fixes (real and pseudoabsences)
viii) weight2 <- Weighted data point of 5 assigned to all real GPS fixes and 1 for pseudoabsences
ix) intensity <- Field-specific classification of shooting intensity per